Module features

Module features 

Structs

Blocking
Configuration options for the Blocking Queries feature.
Features
A set of features which can be applied to an endpoint request.
FeaturesBuilder
Builder for Features.

Enums

ConsistencyMode
Configuration options for the Consistency Mode feature.
FeaturesBuilderError
Error type for FeaturesBuilder

Traits

FeaturedEndpoint
An Endpoint which contains optional Features for modifying how its generated request is handled.