Structs
- Blocking
- Configuration options for the Blocking Queries feature.
- Features
- A set of features which can be applied to an endpoint request.
- Features
Builder - Builder for
Features.
Enums
- Consistency
Mode - Configuration options for the Consistency Mode feature.
- Features
Builder Error - Error type for FeaturesBuilder
Traits
- Featured
Endpoint - An Endpoint which contains optional Features for modifying how its generated request is handled.